@@ -1,8 +1,9 @@
 /*
-* Copyright 2006 Milan Digital Audio LLC
-* Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
-* License GPL-2.0 or later (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
-*/
+ * Copyright 2006 Milan Digital Audio LLC
+ * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * License GPL-2.0 or later
+ * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
+ */
 
 #ifndef GOCONDITION_H
 #define GOCONDITION_H
@@ -12,20 +13,16 @@
 #elif defined WX_MUTEX
 #include <wx/thread.h>
 #else
-#include "atomic.h"
 #include "GOWaitQueue.h"
+#include "atomic.h"
 #endif
 
 #include "GOMutex.h"
 #include "GOThread.h"
 
-class GOCondition
-{
+class GOCondition {
 public:
-  enum {
-    SIGNAL_RECEIVED = 0x1,
-    MUTEX_LOCKED = 0x2
-  };
+  enum { SIGNAL_RECEIVED = 0x1, MUTEX_LOCKED = 0x2 };
 
 private:
 #if defined GO_STD_MUTEX
@@ -36,15 +33,17 @@ private:
 #else
   atomic_int m_Waiters;
   GOWaitQueue m_Wait;
-  GOMutex& m_Mutex;
+  GOMutex &m_Mutex;
 #endif
 
-  GOCondition(const GOCondition&) = delete;
-  const GOCondition& operator=(const GOCondition&) = delete;
+  GOCondition(const GOCondition &) = delete;
+  const GOCondition &operator=(const GOCondition &) = delete;
+
+  unsigned DoWait(
+    bool isWithTimeout, const char *waiterInfo, GOThread *pThread);
 
-  unsigned DoWait(bool isWithTimeout, const char* waiterInfo, GOThread *pThread);
 public:
-  GOCondition(GOMutex& mutex);
+  GOCondition(GOMutex &mutex);
   ~GOCondition();
 
   /**
@@ -53,7 +52,7 @@ public:
    * After return tries to reaqquire mutex lock
    * @return the bit combination of SIGNAL_RECEIVED and MUTEX_RELOCKED
    */
-  unsigned WaitOrStop(const char* waiterInfo = NULL, GOThread* pThread = NULL);
+  unsigned WaitOrStop(const char *waiterInfo = NULL, GOThread *pThread = NULL);
   void Wait() { WaitOrStop(NULL, NULL); }
   void Signal();
   void Broadcast();
