@@ -1,8 +1,9 @@
 /*
-* Copyright 2006 Milan Digital Audio LLC
-* Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
-* License GPL-2.0 or later (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
-*/
+ * Copyright 2006 Milan Digital Audio LLC
+ * Copyright 2009-2021 GrandOrgue contributors (see AUTHORS)
+ * License GPL-2.0 or later
+ * (https://www.gnu.org/licenses/old-licenses/gpl-2.0.html).
+ */
 
 #ifndef GO_STD_MUTEX
 
@@ -10,25 +11,22 @@
 #include <chrono>
 #endif
 
-#include "threading_impl.h"
 #include "GOWaitQueue.h"
+#include "threading_impl.h"
 
-GOWaitQueue::GOWaitQueue()
-{
+GOWaitQueue::GOWaitQueue() {
 #ifdef GOWAITQUEUE_USE_STD_MUTEX
   m_Wait.lock();
 #endif
 }
 
-GOWaitQueue::~GOWaitQueue()
-{
+GOWaitQueue::~GOWaitQueue() {
 #ifdef GOWAITQUEUE_USE_STD_MUTEX
   m_Wait.unlock();
 #endif
 }
 
-void GOWaitQueue::WaitInfinitely()
-{
+void GOWaitQueue::WaitInfinitely() {
 #ifdef GOWAITQUEUE_USE_WX
   m_Wait.Wait();
 #elif defined(GOWAITQUEUE_USE_STD_MUTEX)
@@ -36,8 +34,7 @@ void GOWaitQueue::WaitInfinitely()
 #endif
 }
 
-bool GOWaitQueue::WaitWithTimeout()
-{
+bool GOWaitQueue::WaitWithTimeout() {
 #ifdef GOWAITQUEUE_USE_WX
   return m_Wait.WaitTimeout(WAIT_TIMEOUT_MS) != wxSEMA_TIMEOUT;
 #elif defined(GOWAITQUEUE_USE_STD_MUTEX)
@@ -45,23 +42,19 @@ bool GOWaitQueue::WaitWithTimeout()
 #endif
 }
 
-bool GOWaitQueue::Wait(bool isWithTimeout)
-{
+bool GOWaitQueue::Wait(bool isWithTimeout) {
   bool rc;
 
   if (isWithTimeout)
     rc = WaitWithTimeout();
-  else
-  {
+  else {
     WaitInfinitely();
     rc = true;
   }
   return rc;
 }
 
-
-void GOWaitQueue::Wakeup()
-{
+void GOWaitQueue::Wakeup() {
 #ifdef GOWAITQUEUE_USE_WX
   m_Wait.Post();
 #elif defined(GOWAITQUEUE_USE_STD_MUTEX)
