@@ -24,25 +24,30 @@
 
 #include <wx/app.h>
 #include <wx/cmdline.h>
+
 #include <vector>
 
-class GOTool  : public wxAppConsole
-{
+class GOTool : public wxAppConsole {
 private:
-	wxLocale m_locale;
-	static const wxCmdLineEntryDesc m_cmdLineDesc [];
+  wxLocale m_locale;
+  static const wxCmdLineEntryDesc m_cmdLineDesc[];
 
-	bool OnInit();
-	int OnRun();
-	void OnInitCmdLine(wxCmdLineParser& parser);
-	bool OnCmdLineParsed(wxCmdLineParser& parser);
+  bool OnInit();
+  int OnRun();
+  void OnInitCmdLine(wxCmdLineParser &parser);
+  bool OnCmdLineParsed(wxCmdLineParser &parser);
 
-	bool CmdLineCreate(wxCmdLineParser& parser);
+  bool CmdLineCreate(wxCmdLineParser &parser);
 
-	bool CreateOrganPackage(wxString organPackage, wxString title, wxString inputDirectory, std::vector<wxString> odfs, std::vector<wxString> packages);
+  bool CreateOrganPackage(
+    wxString organPackage,
+    wxString title,
+    wxString inputDirectory,
+    std::vector<wxString> odfs,
+    std::vector<wxString> packages);
 
 public:
-	GOTool();
+  GOTool();
 };
 
 DECLARE_APP(GOTool)
